@@ -37,10 +37,18 @@ class TraceCommands(BaseCommand):
                   help="Storage driver's connection string. Defaults to "
                        "env[OSPROFILER_CONNECTION_STRING] if set, else "
                        "ceilometer://")
+    @cliutils.arg("--transport-url", dest="transport_url",
+                  help="Oslo.messaging transport URL (for messaging:// driver "
+                       "only), e.g. rabbit://user:password@host:5672/")
+    @cliutils.arg("--idle-timeout", dest="idle_timeout", type=int, default=1,
+                  help="How long to wait for the trace to finish, in seconds "
+                       "(for messaging:// driver only)")
     @cliutils.arg("--json", dest="use_json", action="store_true",
                   help="show trace in JSON")
     @cliutils.arg("--html", dest="use_html", action="store_true",
                   help="show trace in HTML")
+    @cliutils.arg("--local-libs", dest="local_libs", action="store_true",
+                  help="use local static files of html in /libs/")
     @cliutils.arg("--dot", dest="use_dot", action="store_true",
                   help="show trace in DOT language")
     @cliutils.arg("--render-dot", dest="render_dot_filename",
@@ -87,6 +95,10 @@ class TraceCommands(BaseCommand):
                     "$DATA", json.dumps(trace, indent=4,
                                         separators=(",", ": "),
                                         default=datetime_json_serialize))
+                if args.local_libs:
+                    output = output.replace("$LOCAL", "true")
+                else:
+                    output = output.replace("$LOCAL", "false")
         elif args.use_dot:
             dot_graph = self._create_dot_graph(trace)
             output = dot_graph.source
